log

package
v0.0.0-...-48788f6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 18, 2023 License: MIT Imports: 7 Imported by: 0

README

Log Service

A super simple logger that accepts a string and appends to an app.log text file.

Get started

Build the log command service using the service handler.

go build ./cmd/logservice

Then start the logservice and create logs via an HTTP POST request.

./logservice

curl --request POST \
    --url http://localhost:4000/log \
    --data "<Message>"

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterHandlers

func RegisterHandlers()

func Run

func Run(dest string)

func SetClientLogger

func SetClientLogger(serviceURL string, clientService registry.ServiceName)

Types

This section is empty.

Jump to